function [ count ] = estHfmBasis( samplingFrequency, blockLength )
%HFMBASIS Estimates number of HFM waveforms.

timeIndices = (0:blockLength-1)';
times = timeIndices / samplingFrequency;

noOfFrequencies = blockLength / 2;
frequencyIndices = (0:noOfFrequencies);
frequencies = frequencyIndices / noOfFrequencies * samplingFrequency / 2;

dkLFM = @(f, k) ( samplingFrequency^2 / (f * blockLength^2 + eps) );
dkHFM = @(f, k) 2*( dkLFM(f, k) -  4/3 * dkLFM(f, k) * blockLength / samplingFrequency * k );
lowerKHFM = @(f) ( -samplingFrequency / blockLength );
upperKHFM = @(f) ( min((samplingFrequency - 2*f) / blockLength, samplingFrequency/(2*blockLength)) );
nextUpperK = @(f, k) ( (k + dkHFM(f,k) + dkLFM(f,k)) / (1 - dkHFM(f,1) + dkLFM(f,k)) ); 
nextLowerK = @(f, k) ( (k - dkHFM(f,k) - dkLFM(f,k)) / (1 + dkHFM(f,1) - dkLFM(f,k)) ); 

currentIndex = 1;

for frequencyIndex = 1:noOfFrequencies
    frequency = frequencies(frequencyIndex);
    
    k = upperKHFM( frequency );
    
    while ( k >= lowerKHFM( frequency ) )
        finalFrequency = frequency / ( 1 - k * blockLength / samplingFrequency + eps );
        
        if( finalFrequency < 0 || finalFrequency > samplingFrequency / 2 )
            k = k - dkHFM(frequency, k);
%            k = nextLowerK(frequency, k);
            continue;
        end
        

        currentIndex = currentIndex + 1;
        k = k - dkHFM(frequency, k);
        
        % Just get the end points.
        if ( k < lowerKHFM( frequency ) )
            k = lowerKHFM( frequency );

            %currentIndex = currentIndex + 1;
            k = k - dkHFM(frequency, k);
        end
    end
end

count = currentIndex - 1;

end

