function [ count ] = estLfmBasis( samplingFrequency, blockLength )
%CREATELFMBASIS Estimates number of basis vectors.

timeIndices = (0:blockLength-1)';
times = timeIndices / samplingFrequency;
timesSquared = times.^2;

noOfFrequencies = blockLength / 2;
frequencyIndices = (0:noOfFrequencies);
frequencies = frequencyIndices / noOfFrequencies * samplingFrequency / 2;

dkLFM = @(f, k) 2 * ( samplingFrequency^2 / (f * blockLength^2 + eps) );
lowerKLFM = @(f) ( -samplingFrequency / (2*blockLength) );
upperKLFM = @(f) ( samplingFrequency / blockLength );

currentIndex = 1;

for frequencyIndex = 1:noOfFrequencies
    frequency = frequencies(frequencyIndex);
    
    k = lowerKLFM( frequency );
    
    while ( k <= upperKLFM( frequency ) )
        finalFrequency = frequency * ( 1 + k * blockLength / samplingFrequency );
        
        if( finalFrequency < 0 || finalFrequency > samplingFrequency / 2 )
            k = k + dkLFM(frequency, k);
            continue;
        end
        
        currentIndex = currentIndex + 1;
        k = k + dkLFM(frequency, k);
    end
end

count = currentIndex-1;

end

