function [ basis, descriptor, sums ] = hfmBasis( samplingFrequency, blockLength, measurementBasis )
%HFMBASIS Creates a basis of HFM waveforms.

timeIndices = (0:blockLength-1)';
times = timeIndices / samplingFrequency;

noOfFrequencies = blockLength / 2;
frequencyIndices = (0:noOfFrequencies);
frequencies = frequencyIndices / noOfFrequencies * samplingFrequency / 2;

dkLFM = @(f, k) ( samplingFrequency^2 / (f * blockLength^2 + eps) );
%dkHFMGradient = @(n) ( (2*(1-n^2)*log((1+n)/(1-n))-4*n) / ((1-n^2)*log(1-n^2) + 2*n) );
%dkHFM = @(f, k) 2 * ( dkLFM(f, k) - dkHFMGradient( dkLFM(f,k)*blockLength/(2*samplingFrequency) ) * k );
dkHFM = @(f, k) 2 * ( dkLFM(f, k) -  4/3 * dkLFM(f, k) * blockLength / samplingFrequency * k );
lowerKHFM = @(f) ( -samplingFrequency / blockLength );
upperKHFM = @(f) ( min((samplingFrequency - 2*f) / blockLength, samplingFrequency/(2*blockLength)) );

averageNumberOfLevels = blockLength / 4; % An estimate.

noOfSignatures = noOfFrequencies * averageNumberOfLevels;
basis = zeros(blockLength, noOfSignatures);
descriptor = zeros(2, noOfSignatures);

currentIndex = 1;

for frequencyIndex = 1:noOfFrequencies
    frequency = frequencies(frequencyIndex);
    
    k = upperKHFM( frequency );
    
    while ( k >= lowerKHFM( frequency ) )
        finalFrequency = frequency / ( 1 - k * blockLength / samplingFrequency + eps );
        
        if( finalFrequency < 0 || finalFrequency > samplingFrequency / 2 )
            k = k - dkHFM(frequency, k);
            continue;
        end
        
        descriptor(:, currentIndex) = [frequency; k];
        if ( k == 0)
            basis(:, currentIndex) = exp( -2*pi*1i*frequency*times ) / sqrt(blockLength);
        else
            basis(:, currentIndex) = exp( -2*pi*1i*frequency/k * log(1 - k*times) ) / sqrt(blockLength);
        end

        currentIndex = currentIndex + 1;
        k = k - dkHFM(frequency, k);
        
        % Just get the end points.
        if ( k < lowerKHFM( frequency ) )
            k = lowerKHFM( frequency );
            
            descriptor(:, currentIndex) = [frequency; k];
            if ( k == 0)
                basis(:, currentIndex) = exp( -2*pi*1i*frequency*times ) / sqrt(blockLength);
            else
                basis(:, currentIndex) = exp( -2*pi*1i*frequency/k * log(1 - k*times) ) / sqrt(blockLength);
            end

            currentIndex = currentIndex + 1;
            k = k - dkHFM(frequency, k);
        end
    end
end

basis = basis(:, 1:currentIndex-1);
descriptor = descriptor(:, 1:currentIndex-1);

if ( nargin == 3 )
    % Compressive basis.
    basis = measurementBasis * basis;
end

sums = zeros(2, currentIndex-1);
sums(1, :) = sum(basis.^2);
sums(2, :) = sum(abs(basis).^2);

end

