function [ basis, descriptor, sums ] = lfmBasis( samplingFrequency, blockLength, measurementBasis )
%CREATELFMBASIS Creates a basis of LFM waveforms.

timeIndices = (0:blockLength-1)';
times = timeIndices / samplingFrequency;
timesSquared = times.^2;

noOfFrequencies = blockLength / 2;
frequencyIndices = (0:noOfFrequencies);
frequencies = frequencyIndices / noOfFrequencies * samplingFrequency / 2;

dkLFM = @(f, k) 2 * ( samplingFrequency^2 / (f * blockLength^2 + eps) );
lowerKLFM = @(f) ( -samplingFrequency / (2*blockLength) );
upperKLFM = @(f) ( samplingFrequency / blockLength );

averageNumberOfLevels = blockLength / 4; % Max is N/2, minimium is 0.

noOfSignatures = noOfFrequencies * averageNumberOfLevels;
basis = zeros(blockLength, noOfSignatures);
descriptor = zeros(2, noOfSignatures);

currentIndex = 1;

for frequencyIndex = 1:noOfFrequencies
    frequency = frequencies(frequencyIndex);
    
    k = lowerKLFM( frequency );
    
    while ( k <= upperKLFM( frequency ) )
        finalFrequency = frequency * ( 1 + k * blockLength / samplingFrequency );
        
        if( finalFrequency < 0 || finalFrequency > samplingFrequency / 2 )
            k = k + dkLFM(frequency, k);
            continue;
        end
        
        descriptor(:, currentIndex) = [frequency; k];
        basis(:, currentIndex) = exp( 2*pi*1i*frequency*(times + 0.5*k*timesSquared) ) / sqrt(blockLength);
        
        currentIndex = currentIndex + 1;
        k = k + dkLFM(frequency, k);
    end
end

basis = basis(:, 1:currentIndex-1);
descriptor = descriptor(:, 1:currentIndex-1);

if ( nargin == 3 )
    % Compressive basis.
    basis = measurementBasis * basis;
end

sums = zeros(2, currentIndex-1);
sums(1, :) = sum(basis.^2);
sums(2, :) = sum(abs(basis).^2);

end

