function [ targetData ] = narrowbandTarget( strengths, noOfTimeSamples, samplingFrequency, frequencies )
%NARROWBANDTARGET - Creates a narrowband target.
% strengths -- strength of lines in dB; scalar to be valid for all lines.
% frequencies -- list of frequency lines.
%

noOfFrequencies = length(frequencies);

if ( length(strengths) == 1 )
    strengths = repmat(strengths, 1, noOfFrequencies);
end

phases = rand(noOfFrequencies, 1) * 2*pi;

timeIndices = (0:noOfTimeSamples-1)';
timeValues = timeIndices /samplingFrequency;

targetData = zeros(noOfTimeSamples, noOfFrequencies);

for frequencyIndex = 1:noOfFrequencies
    strength = strengths(frequencyIndex);
    frequency = frequencies(frequencyIndex);
    phase = phases(frequencyIndex);

    targetData(:, frequencyIndex) = sqrt(2) * 10^(strength/20)*sin(2*pi*frequency*timeValues + phase);
end

targetData = sum(targetData, 2);

end

