function [ targetData ] = pingerTarget( strengths, noOfTimeSamples, samplingFrequency, pings, frequencyRanges )
%PINGERTARGET - Creates a pinger target. Pings stretched to fit within samples.
% strengths -- strength of pings in dB; scalar to be valid for all pings.
% pingTypes -- cell list of 'HFM, 'LFM', 'CW', 'NA' strings for each ping. Eg pings = {'HFM' 'CW'}
% frequencyRanges -- each column is parameters for a ping. F0 to F1.
%

noOfPings = length(pings);

if ( length(strengths) == 1 )
    strengths = repmat(strengths, noOfPings);
end

targetData = zeros(noOfTimeSamples, 1);

noOfSamples = floor(noOfTimeSamples / noOfPings);

for pingIndex = 1:noOfPings
    strength = 10^(strengths(pingIndex)/20);
    ping = pings(pingIndex);
    frequencyRange = frequencyRanges(:, pingIndex);

    if ( strcmpi('CW', ping) == 1 )
        pingData = sqrt(2) * strength * CW( frequencyRange(1), samplingFrequency, noOfSamples );
    elseif ( strcmpi('LFM', ping) == 1 )
        pingData = sqrt(2) * strength * LFM( frequencyRange(1), frequencyRange(2), samplingFrequency, noOfSamples );
    elseif ( strcmpi('HFM', ping) == 1 )
        pingData = sqrt(2) * strength * HFM( frequencyRange(1), frequencyRange(2), samplingFrequency, noOfSamples );
    elseif ( strcmpi('NA', ping) == 1 )
        continue;
    else
        disp('Invalid ping type.');
        return;
    end

    targetData((pingIndex-1)*noOfSamples+1:pingIndex*noOfSamples, 1) = real(pingData);
end

end

