function [ targetData, targetDirections ] = scenario01( samplingFrequency, timeDuration )
%SCENARIO01
% Test case for passive sonar.
% Target #1:
%   - Bearing: 100 degrees.
%   - Strength: -5 dB
%   - Broadband
%   - Narrowband: fs/5
%
% Target #2:
%   - Bearing: -50 degrees
%   - Strength: 0 dB 
%   - Broadband
%
% Target #3:
%   - Bearing: 30 degrees
%   - Strength: 5 dB
%   - Pings: HFM (fs/18, fs/8), CW (fs/6)
%

targetBearings = [100; -50; 30]*pi/180;
targetStrengths = [-5, 0, 5];
noOfTargets = length(targetBearings);

targetDirections = [cos(targetBearings), sin(targetBearings)];

noOfTimeSamples = round(timeDuration * samplingFrequency);

targetData = zeros(noOfTimeSamples, noOfTargets);

targetData(:, 1) = broadbandTarget( targetStrengths(1), noOfTimeSamples, samplingFrequency ) + narrowbandTarget( targetStrengths(1), noOfTimeSamples, samplingFrequency, samplingFrequency/5);

targetData(:, 2) = broadbandTarget( targetStrengths(2), noOfTimeSamples, samplingFrequency );

targetData(:, 3) = pingerTarget( targetStrengths(3), noOfTimeSamples, samplingFrequency, {'HFM' 'CW'}, samplingFrequency * [1/18, 1/8; 1/6, 1/6]' );

targetData = fft(targetData);
targetData(1, :) = 0;
targetData(noOfTimeSamples/2+1, :) = 0;
targetData = real(ifft(targetData));

end

