function [ targetData, targetDirections ] = scenario03( samplingFrequency, timeDuration )
%SCENARIO02
% Pulse:
%   - HFM (fs/18, fs/8), 1/4 of timeDuration
%
% Targets:
%   - Bearings      [-70, 30, 100] degrees
%   - Delays        [0, 0.2, 0.3] of time duration
%   - Strengths     [10, 5, 0] dB
%

targetBearings = [-70; 30; 30; 100]*pi/180;
targetStrengths = [0, 0, 0, 0];
targetDelays = [0, 0.0, 0.5, 0.6] * timeDuration;
noOfTargets = length(targetBearings);

targetDirections = [cos(targetBearings), sin(targetBearings)];

noOfTimeSamples = round(timeDuration * samplingFrequency);
noOfPingSamples = round(noOfTimeSamples / 4);

targetData = zeros(noOfTimeSamples, noOfTargets);

for targetIndex = 1:noOfTargets
    ping = pingerTarget( targetStrengths(targetIndex), noOfPingSamples, samplingFrequency, {'HFM'}, samplingFrequency * [1/18, 1/8]' );
    
    insertStartIndex = max(1, round(targetDelays(targetIndex) * samplingFrequency));
    insertStopIndex = min(noOfTimeSamples, insertStartIndex + noOfPingSamples) - 1;
    
    extractStartIndex = 1;
    extractStopIndex = insertStopIndex - insertStartIndex + 1;
    
    targetData(insertStartIndex:insertStopIndex, targetIndex) = ping(extractStartIndex:extractStopIndex);
end


targetData = fft(targetData);
targetData(1, :) = 0;
targetData(noOfTimeSamples/2+1, :) = 0;
targetData = real(ifft(targetData));

end

