function [  targetData, targetDirections ] = scenario06( samplingFrequency, timeDuration )
%SCENARIO06
% Test case for passive sonar.
% Target #1:
%   - Bearing: 20 degrees.
%   - Strength: -5 dB
%   - Broadband
%   - Narrowband: 50 Hz
%
% Target #2:
%   - Bearing: -50 degrees
%   - Strength: 0 dB 
%   - Broadband
%
% Target #3:
%   - Bearing: 30 degrees
%   - Strength: 5 dB
%   - Pings: HFM [2kHz to 4kHz]
%

targetBearings = [20; -50; 30]*pi/180;
targetStrengths = [0, 5, 20];
noOfTargets = length(targetBearings);

targetDirections = [cos(targetBearings), sin(targetBearings)];

noOfTimeSamples = round(timeDuration * samplingFrequency);

targetData = zeros(noOfTimeSamples, noOfTargets);

targetData(:, 1) = broadbandTarget( targetStrengths(1), noOfTimeSamples, samplingFrequency ) + 0*narrowbandTarget( 35+targetStrengths(1), noOfTimeSamples, samplingFrequency, 100);

targetData(:, 2) = broadbandTarget( targetStrengths(2), noOfTimeSamples, samplingFrequency );

targetData(:, 3) = pingerTarget( targetStrengths(3), noOfTimeSamples, samplingFrequency, {'NA','HFM','NA'}, [0, 0; 2000, 4000; 0, 0]' );

targetData = fft(targetData);
targetData(1, :) = 0;
targetData(noOfTimeSamples/2+1, :) = 0;
targetData = real(ifft(targetData));

end

