function [  targetData, targetDirections ] = scenario08( samplingFrequency, timeDuration )
%SCENARIO08
% Test case for active sonar.
% Pulse:
%   - HFM (2kHz, 4kHz), 1/4 of timeDuration
%
% Targets:
%   - Bearings      [-70, 30, 100] degrees
%   - Delays        [0, 0.0, 0.2] of time duration
%   - Strengths     [10, 10, 10] dB
%

noOfTimeSamples = round(timeDuration * samplingFrequency);
noOfPingSamples = round(noOfTimeSamples * 2/3);
pingDuration = noOfPingSamples / samplingFrequency;


targetBearings = [-70; 100; 30]*pi/180;
targetStrengths = [-inf, -inf, -inf];
targetReflectionStrengths = [20, 20, 20];
targetDelays = [0, 0.0, 1/3] * pingDuration;
noOfTargets = length(targetBearings);

targetDirections = [cos(targetBearings), sin(targetBearings)];

targetData = zeros(noOfTimeSamples, noOfTargets);

for targetIndex = 1:noOfTargets
    ping = pingerTarget( targetReflectionStrengths(targetIndex), noOfPingSamples, samplingFrequency, {'HFM'}, [25000, 30000]' );
    
    insertStartIndex = max(1, round(targetDelays(targetIndex) * samplingFrequency));
    insertStopIndex = min(noOfTimeSamples, insertStartIndex + noOfPingSamples) - 1;
    
    extractStartIndex = 1;
    extractStopIndex = insertStopIndex - insertStartIndex + 1;
    
    targetData(insertStartIndex:insertStopIndex, targetIndex) = ping(extractStartIndex:extractStopIndex);
end

for targetIndex = 1:noOfTargets
    targetData(:,targetIndex) = targetData(:,targetIndex) + broadbandTarget( targetStrengths(targetIndex), noOfTimeSamples, samplingFrequency );
end

targetData = fft(targetData);
targetData(1, :) = 0;
targetData(noOfTimeSamples/2+1, :) = 0;
targetData = real(ifft(targetData));
end
