function [ sensorPositions, sensorSpacing ] = CYL( noOfSensors, directionVector )
% Creates circular array with sensors in 2 dimensions.
%
% noOfSensors -- number of sensors.
% directionVector -- direction from the origin to the first sensor; scalar indicates along x-axis.

if ( length(directionVector) == 1 )
    directionVector = [directionVector; 0];
end

sensorIndices = (0:noOfSensors-1);
sensorRadius = norm(directionVector);

angle = atan2(directionVector(2), directionVector(1));

sensorPositions = sensorRadius * [cos(sensorIndices * 2*pi/noOfSensors + angle); sin(sensorIndices * 2*pi/noOfSensors + angle)];
sensorSpacing = sensorRadius * 2*sin(pi/noOfSensors);

end

