function [solution, activeSet] = DCSSOMP(A, Y, e, u, C)
% Distributed Compressive Sensing Simultanous Orthogonal Matching Pursuit.
% A - System matrix of size MxN.
% Y - Compressive measurement matrix of size MxR.
% e - Acceptable relative error (value between zero to one).
% u - Maximum dictionary coherence.
% C - Dictionary coherence.
%
% C and u are optional parameters and used with heavily non-orthogonal / coherent dictionaries.
%

[M, N] = size(A);
[M, J] = size(Y);


% Initialize.
counter = 1;

orthogonalCoefficients = zeros(M, J);

selectedIndices = [];
selectedBasisVectors = zeros(M, 0);

residual = Y;

yNorm = sqrt(sum(abs(Y).^2));
aNorm = sqrt(sum(abs(A).^2));

result = 0;

if ( nargin < 4 )
    u = 0;
end

while ( result == 0 && counter <= M/2)
  % Select with penalizied coherent dictionary.
  canidateWeights = sum(abs(residual' * A),1) ./ aNorm;

  while ( 1 )
    [value, selectedIndex] = max( canidateWeights );
    if ( sum(selectedIndices == selectedIndex) == 1 )
      break;
    end

    if ( u == 0 )
        break;
    end

    coherence = C(selectedIndex, :);
      
    if ( max(coherence(selectedIndices)) > u )
     canidateWeights(selectedIndex) = 0;
    else
      break;
    end
  end
  
  selectedIndices = [selectedIndices, selectedIndex];

  % Select.
%  [value, selectedIndex] = max( sum(abs(residual' * A),1) ./ aNorm );
%  if ( sum(selectedIndices == selectedIndex) == 1 )
%    break;
%  end
%  selectedIndices = [selectedIndices, selectedIndex];


  % Orthogonalize.
  selectedBasisVector = A(:, selectedIndex);
  selectedBasisVector = selectedBasisVector - selectedBasisVectors * (selectedBasisVector' * selectedBasisVectors)';
  selectedBasisVector = selectedBasisVector / norm(selectedBasisVector);
  selectedBasisVectors = [selectedBasisVectors, selectedBasisVector];


  % Iterate.
  orthogonalCoefficients(counter,:) = selectedBasisVector' * residual;
  residual = residual -  selectedBasisVector * orthogonalCoefficients(counter,:);

  % Check for convergence.
  if ( sum( sqrt(sum(residual.^2)) > e*yNorm ) == J )
    counter = counter + 1;
  else
    result = 1;
  end
end

% De-orthogonalize.
mutilatedBasis = A(:, selectedIndices);
[Q, R] = qr(mutilatedBasis);

for l = 1:size(selectedBasisVectors, 2)
  if ( sign(selectedBasisVectors(1,l)) ~= sign(Q(1,l)) )
    R(l,:) = -R(l,:);
  end
end

solution = zeros(N, J);
solution(selectedIndices', :) = R \ orthogonalCoefficients;
activeSet = selectedIndices;



