function [ pulse ] = HFM( startFrequency, stopFrequency, samplingFrequency, noOfSamples, phase )
% Creates a HFM pulse with unit amplitude.
%
% startFrequency - normalized frequency (= desired frequency / samplingFrequency)
% stopFrequency - normalized frequency (= desired frequency / samplingFrequency)
% noOfSamples - length of pulse.

f0 = startFrequency;
f1 = stopFrequency;
Fs = samplingFrequency;
N = noOfSamples;

t = (0:N-1)' / Fs;
T = N/Fs;
B = f1 - f0;

if ( nargin < 5 )
    phase = rand*2*pi;
end

if ( B == 0 )
    pulse = CW( startFrequency, samplingFrequency, noOfSamples, phase );
else
    pulse = exp(-2*pi*1i*f0*f1*T/B * log(f1*T - B*t) + 1i*phase);
end

end

