function [ sensorData ] = createSensorData( samplingFrequency, speedOfSound, sensorPositions, targetData, targetDirections, noiseLevel )
%CREATESENSORDATA Creates sensordata for a given sensor configuration and target configuration.

[noOfTimeSamples, noOfTargets] = size(targetData);

noOfSensors = size(sensorPositions, 2);

frequencyIndices = [(0:noOfTimeSamples/2)'; (1:noOfTimeSamples/2-1)' - noOfTimeSamples/2];
frequencies = frequencyIndices * samplingFrequency / noOfTimeSamples;

sensorData = zeros(noOfTimeSamples, noOfSensors);
sensorDelays = targetDirections * sensorPositions / speedOfSound;

for targetIndex = 1:noOfTargets
    timeDelayMatrix = exp(-2*pi*1i*frequencies*sensorDelays(targetIndex,:));
    targetDataMatrix = repmat(targetData(:,targetIndex), 1, noOfSensors);
    sensorData = sensorData + real(ifft(fft(targetDataMatrix) .* timeDelayMatrix));
end

noiseLevel = 10^(noiseLevel/20);
sensorData = sensorData + noiseLevel*randn(noOfTimeSamples, noOfSensors);


end

